==> mule-standalone-3.1.1.tar.gz: org/mule/config/PreferredObjectSelector.java <==
/*
 * $Id: PreferredObjectSelector.java 20919 2011-01-06 18:51:08Z pablo.kraan $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.config;

import java.util.Comparator;
import java.util.Iterator;

/**
 * Selects a preferred object from a collection of instances of the same type
 * based on the weight of the {@link Preferred} annotation. If there is no
 * preferred instances, then it just returns the first object in the collection.
 */
public class PreferredObjectSelector<T>
{

    private final Comparator<T> comparator;

    public PreferredObjectSelector()
    {
        comparator = new Comparator<T>()
        {
            private PreferredComparator preferredComparator = new PreferredComparator();

            public int compare(T threadPoolFactory, T threadPoolFactory1)
            {
                final Preferred preferred = threadPoolFactory.getClass().getAnnotation(Preferred.class);
                final Preferred preferred1 = threadPoolFactory1.getClass().getAnnotation(Preferred.class);

                return preferredComparator.compare(preferred, preferred1);
            }
        };
    }

    /**
     * Selects a preferred object from instances returned by an {@link Iterator}.
     * <p/>
     * The preferred instance will be the instance annotated with {@link Preferred}
     * annotation with the highest weight attribute if there is any, or a non
     * annotated class otherwise.
     *
     * @param iterator contains the objects to select from
     * @return the preferred instance
     */
    public T select(Iterator<T> iterator)
    {
        T preferred = null;

        if (iterator.hasNext())
        {
            preferred = iterator.next();

            while (iterator.hasNext())
            {
                T current = iterator.next();

                if (comparator.compare(preferred, current) == -1)
                {
                    preferred = current;
                }
            }
        }

        return preferred;
    }
}

==> mule-standalone-3.3.0.tar.gz: org/mule/config/PreferredObjectSelector.java <==
/*
 * $Id: PreferredObjectSelector.java 21835 2011-05-06 18:05:08Z aperepel $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.config;

import java.util.Comparator;
import java.util.Iterator;

/**
 * Selects a preferred object from a collection of instances of the same type
 * based on the weight of the {@link Preferred} annotation. If there is no
 * preferred instances, then it just returns the first object in the collection.
 */
public class PreferredObjectSelector<T>
{

    private final Comparator<T> comparator;

    public PreferredObjectSelector()
    {
        comparator = new Comparator<T>()
        {
            private PreferredComparator preferredComparator = new PreferredComparator();

            public int compare(T candidate1, T candidate2)
            {
                final Preferred preferred = candidate1.getClass().getAnnotation(Preferred.class);
                final Preferred preferred1 = candidate2.getClass().getAnnotation(Preferred.class);

                return preferredComparator.compare(preferred, preferred1);
            }
        };
    }

    /**
     * Selects a preferred object from instances returned by an {@link Iterator}.
     * <p/>
     * The preferred instance will be the instance annotated with {@link Preferred}
     * annotation with the highest weight attribute if there is any, or a non
     * annotated class otherwise.
     *
     * @param iterator contains the objects to select from
     * @return the preferred instance
     */
    public T select(Iterator<T> iterator)
    {
        T preferred = null;

        if (iterator.hasNext())
        {
            preferred = iterator.next();

            while (iterator.hasNext())
            {
                T current = iterator.next();

                if (comparator.compare(preferred, current) == -1)
                {
                    preferred = current;
                }
            }
        }

        return preferred;
    }
}
